@@ -14,6 +14,9 @@
 # limitations under the License.
 
 
+# Error with CAM signature/authentication.
+AUTHFAILURE = 'AuthFailure'
+
 # Failed to create the image.
 FAILEDOPERATION_CREATEBLUEPRINTFAILED = 'FailedOperation.CreateBlueprintFailed'
 
@@ -41,6 +44,9 @@ FAILEDOPERATION_UNABLETOCREATEBLUEPRINT = 'FailedOperation.UnableToCreateBluepri
 # Internal error.
 INTERNALERROR = 'InternalError'
 
+# The disk query returned invalid content.
+INTERNALERROR_DESCRIBEDISKSRETURNABLEERROR = 'InternalError.DescribeDisksReturnableError'
+
 # Failed to query the instance status. Please try again later.
 INTERNALERROR_DESCRIBEINSTANCESTATUS = 'InternalError.DescribeInstanceStatus'
 
@@ -68,9 +74,15 @@ INTERNALERROR_INVALIDCOMMANDNOTFOUND = 'InternalError.InvalidCommandNotFound'
 # There was an error in the request.
 INTERNALERROR_REQUESTERROR = 'InternalError.RequestError'
 
+# Failed to call billing gateway service
+INTERNALERROR_TRADECALLBILLINGGATEWAYFAILED = 'InternalError.TradeCallBillingGatewayFailed'
+
 # Failed to get the price.
 INTERNALERROR_TRADEGETPRICEFAILED = 'InternalError.TradeGetPriceFailed'
 
+# Incorrect parameter.
+INVALIDPARAMETER = 'InvalidParameter'
+
 # Undefined service package ID.
 INVALIDPARAMETER_BUNDLEIDNOTFOUND = 'InvalidParameter.BundleIdNotFound'
 
@@ -215,6 +227,9 @@ INVALIDPARAMETERVALUE_TOOLONG = 'InvalidParameterValue.TooLong'
 # Invalid AZ.
 INVALIDPARAMETERVALUE_ZONEINVALID = 'InvalidParameterValue.ZoneInvalid'
 
+# Reached the upper limit of attached data disks of the instance
+LIMITEXCEEDED_ATTACHDATADISKQUOTALIMITEXCEEDED = 'LimitExceeded.AttachDataDiskQuotaLimitExceeded'
+
 # The firewall rule quota is exceeded.
 LIMITEXCEEDED_FIREWALLRULESLIMITEXCEEDED = 'LimitExceeded.FirewallRulesLimitExceeded'
 
@@ -230,6 +245,15 @@ MISSINGPARAMETER = 'MissingParameter'
 # This instance does not support upgrading packages.
 OPERATIONDENIED_BUNDLENOTSUPPORTMODIFY = 'OperationDenied.BundleNotSupportModify'
 
+# The disk is being created.
+OPERATIONDENIED_DISKCREATING = 'OperationDenied.DiskCreating'
+
+# The disk is being manipulated. Try again later.
+OPERATIONDENIED_DISKOPERATIONINPROGRESS = 'OperationDenied.DiskOperationInProgress'
+
+# The cloud disk type of the disk does not support this operation.
+OPERATIONDENIED_DISKUSAGENOTSUPPORTOPERATION = 'OperationDenied.DiskUsageNotSupportOperation'
+
 # It is not allowed to manipulate this instance, as it is being created.
 OPERATIONDENIED_INSTANCECREATING = 'OperationDenied.InstanceCreating'
 
@@ -251,6 +275,9 @@ RESOURCENOTFOUND_BLUEPRINTIDNOTFOUND = 'ResourceNotFound.BlueprintIdNotFound'
 # The specified image does not exist. Please check whether the `BlueprintId` of the image is correct.
 RESOURCENOTFOUND_BLUEPRINTNOTFOUND = 'ResourceNotFound.BlueprintNotFound'
 
+# The disk ID does not exist.
+RESOURCENOTFOUND_DISKIDNOTFOUND = 'ResourceNotFound.DiskIdNotFound'
+
 # The disk does not exist.
 RESOURCENOTFOUND_DISKNOTFOUND = 'ResourceNotFound.DiskNotFound'
 
@@ -278,6 +305,9 @@ RESOURCENOTFOUND_SNAPSHOTNOTFOUND = 'ResourceNotFound.SnapshotNotFound'
 # The resource is unavailable.
 RESOURCEUNAVAILABLE = 'ResourceUnavailable'
 
+# 
+RESOURCEUNAVAILABLE_BLUEPRINTUNAVAILABLE = 'ResourceUnavailable.BlueprintUnavailable'
+
 # MFA has expired.
 UNAUTHORIZEDOPERATION_MFAEXPIRED = 'UnauthorizedOperation.MFAExpired'
 
@@ -326,6 +356,9 @@ UNSUPPORTEDOPERATION_FIREWALLVERSIONMISMATCH = 'UnsupportedOperation.FirewallVer
 # Unsupported operation: the instance has expired.
 UNSUPPORTEDOPERATION_INSTANCEEXPIRED = 'UnsupportedOperation.InstanceExpired'
 
+# The disk's status does not support this operation.
+UNSUPPORTEDOPERATION_INVALIDDISKSTATE = 'UnsupportedOperation.InvalidDiskState'
+
 # Unsupported operation: the instance status is invalid.
 UNSUPPORTEDOPERATION_INVALIDINSTANCESTATE = 'UnsupportedOperation.InvalidInstanceState'
 
